@@ -28,7 +28,6 @@
 #ifndef FROM_PROJ_CPP
 #define FROM_PROJ_CPP
 #endif
-#define LRU11_DO_NOT_DEFINE_OUT_OF_CLASS_METHODS
 
 #if defined(HAVE_LIBDL) && !defined(_GNU_SOURCE)
 // Required for dladdr() on Cygwin
@@ -57,13 +56,12 @@
 
 #include "proj_config.h"
 
+#ifdef _WIN32
 #if defined(WINAPI_FAMILY) && (WINAPI_FAMILY == WINAPI_FAMILY_APP)
 #define UWP 1
 #else
 #define UWP 0
 #endif
-
-#ifdef _WIN32
 #include <shlobj.h>
 #include <windows.h>
 #else
@@ -76,9 +74,6 @@
 
 //! @cond Doxygen_Suppress
 
-#define STR_HELPER(x) #x
-#define STR(x) STR_HELPER(x)
-
 using namespace NS_PROJ::internal;
 
 NS_PROJ_START
@@ -800,10 +795,9 @@ unsigned long long FileStdio::tell() {
 
 std::unique_ptr<File> FileStdio::open(PJ_CONTEXT *ctx, const char *filename,
                                       FileAccess access) {
-    auto fp = fopen(filename,
-                    access == FileAccess::READ_ONLY
-                        ? "rb"
-                        : access == FileAccess::READ_UPDATE ? "r+b" : "w+b");
+    auto fp = fopen(filename, access == FileAccess::READ_ONLY     ? "rb"
+                              : access == FileAccess::READ_UPDATE ? "r+b"
+                                                                  : "w+b");
     return std::unique_ptr<File>(fp ? new FileStdio(filename, ctx, fp)
                                     : nullptr);
 }
@@ -1011,13 +1005,23 @@ bool FileManager::rename(PJ_CONTEXT *ctx, const char *oldPath,
 
 // ---------------------------------------------------------------------------
 
-std::string FileManager::getProjLibEnvVar(PJ_CONTEXT *ctx) {
-    if (!ctx->env_var_proj_lib.empty()) {
-        return ctx->env_var_proj_lib;
+std::string FileManager::getProjDataEnvVar(PJ_CONTEXT *ctx) {
+    if (!ctx->env_var_proj_data.empty()) {
+        return ctx->env_var_proj_data;
     }
     (void)ctx;
     std::string str;
-    const char *envvar = getenv("PROJ_LIB");
+    const char *envvar = getenv("PROJ_DATA");
+    if (!envvar) {
+        envvar = getenv("PROJ_LIB"); // Legacy name. We should probably keep it
+                                     // for a long time for nostalgic people :-)
+        if (envvar) {
+            pj_log(ctx, PJ_LOG_DEBUG,
+                   "PROJ_LIB environment variable is deprecated, and will be "
+                   "removed in a future release. You are encouraged to set "
+                   "PROJ_DATA instead");
+        }
+    }
     if (!envvar)
         return str;
     str = envvar;
@@ -1035,7 +1039,7 @@ std::string FileManager::getProjLibEnvVar(PJ_CONTEXT *ctx) {
             str = envvar;
     }
 #endif
-    ctx->env_var_proj_lib = str;
+    ctx->env_var_proj_data = str;
     return str;
 }
 
@@ -1387,17 +1391,17 @@ static const char dirSeparator = ';';
 static const char dirSeparator = ':';
 #endif
 
-static const char *proj_lib_name =
-#ifdef PROJ_LIB
-    PROJ_LIB;
+static const char *proj_data_name =
+#ifdef PROJ_DATA
+    PROJ_DATA;
 #else
     nullptr;
 #endif
 
-#ifdef PROJ_LIB_ENV_VAR_TRIED_LAST
-static bool gbPROJ_LIB_ENV_VAR_TRIED_LAST = true;
+#ifdef PROJ_DATA_ENV_VAR_TRIED_LAST
+static bool gbPROJ_DATA_ENV_VAR_TRIED_LAST = true;
 #else
-static bool gbPROJ_LIB_ENV_VAR_TRIED_LAST = false;
+static bool gbPROJ_DATA_ENV_VAR_TRIED_LAST = false;
 #endif
 
 static bool dontReadUserWritableDirectory() {
@@ -1502,10 +1506,10 @@ static void *pj_open_lib_internal(
             sysname = fname.c_str();
         }
 
-        /* if the environment PROJ_LIB defined, and *not* tried as last
+        /* if the environment PROJ_DATA defined, and *not* tried as last
            possibility */
-        else if (!gbPROJ_LIB_ENV_VAR_TRIED_LAST &&
-                 !(projLib = NS_PROJ::FileManager::getProjLibEnvVar(ctx))
+        else if (!gbPROJ_DATA_ENV_VAR_TRIED_LAST &&
+                 !(projLib = NS_PROJ::FileManager::getProjDataEnvVar(ctx))
                       .empty()) {
             fid = open_lib_from_paths(projLib);
         }
@@ -1513,22 +1517,23 @@ static void *pj_open_lib_internal(
         else if ((sysname = get_path_from_relative_share_proj(
                       ctx, name, fname)) != nullptr) {
             /* check if it lives in a ../share/proj dir of the proj dll */
-        } else if (proj_lib_name != nullptr &&
+        } else if (proj_data_name != nullptr &&
                    (fid = open_file(
                         ctx,
-                        (std::string(proj_lib_name) + DIR_CHAR + name).c_str(),
+                        (std::string(proj_data_name) + DIR_CHAR + name).c_str(),
                         mode)) != nullptr) {
 
             /* or hardcoded path */
-            fname = proj_lib_name;
+            fname = proj_data_name;
             fname += DIR_CHAR;
             fname += name;
             sysname = fname.c_str();
         }
 
-        /* if the environment PROJ_LIB defined, and tried as last possibility */
-        else if (gbPROJ_LIB_ENV_VAR_TRIED_LAST &&
-                 !(projLib = NS_PROJ::FileManager::getProjLibEnvVar(ctx))
+        /* if the environment PROJ_DATA defined, and tried as last possibility
+         */
+        else if (gbPROJ_DATA_ENV_VAR_TRIED_LAST &&
+                 !(projLib = NS_PROJ::FileManager::getProjDataEnvVar(ctx))
                       .empty()) {
             fid = open_lib_from_paths(projLib);
         }
@@ -1580,30 +1585,31 @@ std::vector<std::string> pj_get_default_searchpaths(PJ_CONTEXT *ctx) {
         ret.push_back(proj_context_get_user_writable_directory(ctx, false));
     }
 
-    const std::string envPROJ_LIB = NS_PROJ::FileManager::getProjLibEnvVar(ctx);
+    const std::string envPROJ_DATA =
+        NS_PROJ::FileManager::getProjDataEnvVar(ctx);
     const std::string relativeSharedProj = pj_get_relative_share_proj(ctx);
 
-    if (gbPROJ_LIB_ENV_VAR_TRIED_LAST) {
-/* Situation where PROJ_LIB environment variable is tried in last */
-#ifdef PROJ_LIB
-        ret.push_back(PROJ_LIB);
+    if (gbPROJ_DATA_ENV_VAR_TRIED_LAST) {
+/* Situation where PROJ_DATA environment variable is tried in last */
+#ifdef PROJ_DATA
+        ret.push_back(PROJ_DATA);
 #endif
         if (!relativeSharedProj.empty()) {
             ret.push_back(relativeSharedProj);
         }
-        if (!envPROJ_LIB.empty()) {
-            ret.push_back(envPROJ_LIB);
+        if (!envPROJ_DATA.empty()) {
+            ret.push_back(envPROJ_DATA);
         }
     } else {
-        /* Situation where PROJ_LIB environment variable is used if defined */
-        if (!envPROJ_LIB.empty()) {
-            ret.push_back(envPROJ_LIB);
+        /* Situation where PROJ_DATA environment variable is used if defined */
+        if (!envPROJ_DATA.empty()) {
+            ret.push_back(envPROJ_DATA);
         } else {
             if (!relativeSharedProj.empty()) {
                 ret.push_back(relativeSharedProj);
             }
-#ifdef PROJ_LIB
-            ret.push_back(PROJ_LIB);
+#ifdef PROJ_DATA
+            ret.push_back(PROJ_DATA);
 #endif
         }
     }
@@ -1637,15 +1643,18 @@ static NS_PROJ::io::DatabaseContextPtr getDBcontext(PJ_CONTEXT *ctx) {
 /************************************************************************/
 
 std::unique_ptr<NS_PROJ::File>
-NS_PROJ::FileManager::open_resource_file(PJ_CONTEXT *ctx, const char *name) {
+NS_PROJ::FileManager::open_resource_file(PJ_CONTEXT *ctx, const char *name,
+                                         char *out_full_filename,
+                                         size_t out_full_filename_size) {
 
     if (ctx == nullptr) {
         ctx = pj_get_default_ctx();
     }
 
-    auto file = std::unique_ptr<NS_PROJ::File>(
-        reinterpret_cast<NS_PROJ::File *>(pj_open_lib_internal(
-            ctx, name, "rb", pj_open_file_with_manager, nullptr, 0)));
+    auto file =
+        std::unique_ptr<NS_PROJ::File>(reinterpret_cast<NS_PROJ::File *>(
+            pj_open_lib_internal(ctx, name, "rb", pj_open_file_with_manager,
+                                 out_full_filename, out_full_filename_size)));
 
     // Retry with the new proj grid name if the file name doesn't end with .tif
     std::string tmpString; // keep it in this upper scope !
@@ -1661,8 +1670,9 @@ NS_PROJ::FileManager::open_resource_file(PJ_CONTEXT *ctx, const char *name) {
                 if (!filename.empty()) {
                     file.reset(reinterpret_cast<NS_PROJ::File *>(
                         pj_open_lib_internal(ctx, filename.c_str(), "rb",
-                                             pj_open_file_with_manager, nullptr,
-                                             0)));
+                                             pj_open_file_with_manager,
+                                             out_full_filename,
+                                             out_full_filename_size)));
                     if (file) {
                         proj_context_errno_set(ctx, 0);
                     } else {
@@ -1691,8 +1701,9 @@ NS_PROJ::FileManager::open_resource_file(PJ_CONTEXT *ctx, const char *name) {
                 if (!filename.empty()) {
                     file.reset(reinterpret_cast<NS_PROJ::File *>(
                         pj_open_lib_internal(ctx, filename.c_str(), "rb",
-                                             pj_open_file_with_manager, nullptr,
-                                             0)));
+                                             pj_open_file_with_manager,
+                                             out_full_filename,
+                                             out_full_filename_size)));
                     if (file) {
                         proj_context_errno_set(ctx, 0);
                     }
@@ -1717,6 +1728,11 @@ NS_PROJ::FileManager::open_resource_file(PJ_CONTEXT *ctx, const char *name) {
             file =
                 open(ctx, remote_file.c_str(), NS_PROJ::FileAccess::READ_ONLY);
             if (file) {
+                if (out_full_filename) {
+                    strncpy(out_full_filename, remote_file.c_str(),
+                            out_full_filename_size);
+                    out_full_filename[out_full_filename_size - 1] = '\0';
+                }
                 pj_log(ctx, PJ_LOG_DEBUG, "Using %s", remote_file.c_str());
                 proj_context_errno_set(ctx, 0);
             }
@@ -1743,32 +1759,14 @@ NS_PROJ::FileManager::open_resource_file(PJ_CONTEXT *ctx, const char *name) {
  */
 int pj_find_file(PJ_CONTEXT *ctx, const char *short_filename,
                  char *out_full_filename, size_t out_full_filename_size) {
-    auto file = std::unique_ptr<NS_PROJ::File>(
-        reinterpret_cast<NS_PROJ::File *>(pj_open_lib_internal(
-            ctx, short_filename, "rb", pj_open_file_with_manager,
-            out_full_filename, out_full_filename_size)));
-
-    // Retry with the old proj grid name if the file name ends with .tif
-    if (file == nullptr && strstr(short_filename, ".tif") != nullptr) {
-
-        auto dbContext = getDBcontext(ctx);
-        if (dbContext) {
-            try {
-                auto filename = dbContext->getOldProjGridName(short_filename);
-                if (!filename.empty()) {
-                    file.reset(reinterpret_cast<NS_PROJ::File *>(
-                        pj_open_lib_internal(ctx, filename.c_str(), "rb",
-                                             pj_open_file_with_manager,
-                                             out_full_filename,
-                                             out_full_filename_size)));
-                }
-            } catch (const std::exception &e) {
-                pj_log(ctx, PJ_LOG_DEBUG, "%s", e.what());
-                return false;
-            }
-        }
-    }
-
+    const bool old_network_enabled =
+        proj_context_is_network_enabled(ctx) != FALSE;
+    if (old_network_enabled)
+        proj_context_set_enable_network(ctx, false);
+    auto file = NS_PROJ::FileManager::open_resource_file(
+        ctx, short_filename, out_full_filename, out_full_filename_size);
+    if (old_network_enabled)
+        proj_context_set_enable_network(ctx, true);
     return file != nullptr;
 }
 
@@ -1824,6 +1822,17 @@ void pj_load_ini(PJ_CONTEXT *ctx) {
         ctx->ca_bundle_path = ca_bundle_path;
     }
 
+    // Load default value for errorIfBestTransformationNotAvailableDefault
+    // from environment first
+    const char *proj_only_best_default = getenv("PROJ_ONLY_BEST_DEFAULT");
+    if (proj_only_best_default && proj_only_best_default[0] != '\0') {
+        ctx->warnIfBestTransformationNotAvailableDefault = false;
+        ctx->errorIfBestTransformationNotAvailableDefault =
+            ci_equal(proj_only_best_default, "ON") ||
+            ci_equal(proj_only_best_default, "YES") ||
+            ci_equal(proj_only_best_default, "TRUE");
+    }
+
     ctx->iniFileLoaded = true;
     auto file = std::unique_ptr<NS_PROJ::File>(
         reinterpret_cast<NS_PROJ::File *>(pj_open_lib_internal(
@@ -1883,6 +1892,12 @@ void pj_load_ini(PJ_CONTEXT *ctx) {
                 }
             } else if (ca_bundle_path == nullptr && key == "ca_bundle_path") {
                 ctx->ca_bundle_path = value;
+            } else if (proj_only_best_default == nullptr &&
+                       key == "only_best_default") {
+                ctx->warnIfBestTransformationNotAvailableDefault = false;
+                ctx->errorIfBestTransformationNotAvailableDefault =
+                    ci_equal(value, "ON") || ci_equal(value, "YES") ||
+                    ci_equal(value, "TRUE");
             }
         }
 
@@ -1992,3 +2007,13 @@ void proj_context_set_ca_bundle_path(PJ_CONTEXT *ctx, const char *path) {
     } catch (const std::exception &) {
     }
 }
+
+// ---------------------------------------------------------------------------
+
+void pj_stderr_proj_lib_deprecation_warning() {
+    if (getenv("PROJ_LIB") != nullptr && getenv("PROJ_DATA") == nullptr) {
+        fprintf(stderr, "DeprecationWarning: PROJ_LIB environment variable is "
+                        "deprecated, and will be removed in a future release. "
+                        "You are encouraged to set PROJ_DATA instead.\n");
+    }
+}
