@@ -1,17 +1,16 @@
-#define PJ_LIB__
+#define PJ_LIB_
 #include <math.h>
 
 #include "proj.h"
 #include "proj_internal.h"
 
 PROJ_HEAD(eck1, "Eckert I") "\n\tPCyl, Sph";
-#define FC  0.92131773192356127802
-#define RP  0.31830988618379067154
+#define FC 0.92131773192356127802
+#define RP 0.31830988618379067154
 
-
-static PJ_XY eck1_s_forward (PJ_LP lp, PJ *P) {           /* Spheroidal, forward */
-    PJ_XY xy = {0.0,0.0};
-    (void) P;
+static PJ_XY eck1_s_forward(PJ_LP lp, PJ *P) { /* Spheroidal, forward */
+    PJ_XY xy = {0.0, 0.0};
+    (void)P;
 
     xy.x = FC * lp.lam * (1. - RP * fabs(lp.phi));
     xy.y = FC * lp.phi;
@@ -19,10 +18,9 @@ static PJ_XY eck1_s_forward (PJ_LP lp, PJ *P) {           /* Spheroidal, forward
     return xy;
 }
 
-
-static PJ_LP eck1_s_inverse (PJ_XY xy, PJ *P) {           /* Spheroidal, inverse */
-    PJ_LP lp = {0.0,0.0};
-    (void) P;
+static PJ_LP eck1_s_inverse(PJ_XY xy, PJ *P) { /* Spheroidal, inverse */
+    PJ_LP lp = {0.0, 0.0};
+    (void)P;
 
     lp.phi = xy.y / FC;
     lp.lam = xy.x / (FC * (1. - RP * fabs(lp.phi)));
@@ -30,13 +28,10 @@ static PJ_LP eck1_s_inverse (PJ_XY xy, PJ *P) {           /* Spheroidal, inverse
     return (lp);
 }
 
-
-
 PJ *PROJECTION(eck1) {
     P->es = 0.0;
     P->inv = eck1_s_inverse;
     P->fwd = eck1_s_forward;
 
-    return P
-;
+    return P;
 }
